@@ -15,6 +15,7 @@ grammar = {
 		'status':		'Status:\s?(?P<val>.+)'
 	},
 	"_fallback": {
+		'status':		['state:\s*(?P<val>.+)'],
 		'creation_date':	['Created on:\s?(?P<val>.+)',
 					 'Created on\s?[.]*:\s?(?P<val>.+)\.',
 					 'Date Registered\s?[.]*:\s?(?P<val>.+)',
@@ -39,7 +40,8 @@ grammar = {
 					 'Expires\s?[.]*:?\s*?(?P<val>.+)',
 					 'Expire Date\s?[.]*:?\s*?(?P<val>.+)',
 					 'Expired\s?[.]*:?\s*?(?P<val>.+)',
-					 'Domain Expiration Date\s?[.]*:?\s*?(?P<val>.+)'],
+					 'Domain Expiration Date\s?[.]*:?\s*?(?P<val>.+)',
+					 'paid-till:\s*(?P<val>.+)'],
 		'updated_date':		['Database last updated on\s?[.]*:?\s*?(?P<val>.+)\s[a-z]+\.?',
 					 'Record last updated on\s?[.]*:?\s?(?P<val>.+)\.',
 					 'Domain record last updated\s?[.]*:\s*?(?P<val>.+)',
@@ -57,11 +59,13 @@ grammar = {
 					 'Record maintained by:\s?(?P<val>.+)',
 					 'Registration Service Provided By:\s?(?P<val>.+)',
 					 'Registrar of Record:\s?(?P<val>.+)',
+					 'Registrar:\s?(?P<val>.+)',
 					 '\tName:\t\s(?P<val>.+)'],
 		'whois_server':		['Registrar Whois:\s?(?P<val>.+)'],
 		'name_servers':		['(?P<val>[a-z]*d?ns[0-9]+([a-z]{3})?\.([a-z0-9-]+\.)+[a-z0-9]+)',
 					 '(?P<val>[a-z0-9-]+\.d?ns[0-9]*\.([a-z0-9-]+\.)+[a-z0-9]+)',
 					 '(?P<val>([a-z0-9-]+\.)+[a-z0-9]+)(\s+([0-9]{1,3}\.){3}[0-9]{1,3})',
+					 'nserver:\s*(?P<val>[^[\s]+)',
 					 'DNS[0-9]+:\s*(?P<val>.+)',
 					 'ns[0-9]+:\s*(?P<val>.+)',
 					 '[^a-z0-9.-](?P<val>d?ns\.([a-z0-9-]+\.)+[a-z0-9]+)'],
@@ -156,7 +160,12 @@ def whois(domain):
 	
 	data = {}
 	
-	ping = subprocess.Popen(["jwhois", unicodedammit(domain).encode('idna')], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
+	try:
+		encoded_domain = unicodedammit(domain).encode('idna')
+	except UnicodeError, e:
+		encoded_domain = domain
+	
+	ping = subprocess.Popen(["jwhois", "-i", encoded_domain], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
 	out, error = ping.communicate()
 	
 	for line in out.splitlines():
